#!/bin/sh
emacs_is_beta=
emacs_major_version=21
emacs_minor_version=4
emacs_beta_version=7
emacs_kit_version=
xemacs_codename="Economic Science"
infodock_major_version=4
infodock_minor_version=0
infodock_build_version=8
